@@ -10,17 +10,35 @@ require('/docker/whp/web/libs/delegated_user_manager.php');
 function is_api_endpoint() {
     $script_path = $_SERVER['SCRIPT_FILENAME'];
     $request_uri = $_SERVER['REQUEST_URI'];
-    
+
     // Check if the script is in the API directory
     if (strpos($script_path, '/docker/whp/web/api/') !== false) {
         return true;
     }
-    
+
     // Check if the request URI starts with /api/
     if (strpos($request_uri, '/api/') === 0) {
         return true;
     }
-    
+
+    return false;
+}
+
+// Function to check if current request is to the health check endpoint (no auth required)
+function is_health_check_endpoint() {
+    $script_path = $_SERVER['SCRIPT_FILENAME'];
+    $request_uri = $_SERVER['REQUEST_URI'];
+
+    // Check if the script is health.php
+    if (strpos($script_path, '/api/health.php') !== false) {
+        return true;
+    }
+
+    // Check if the request URI is for health check
+    if (strpos($request_uri, '/api/health.php') !== false) {
+        return true;
+    }
+
     return false;
 }
 
@@ -95,6 +113,12 @@ function get_csrf_token() {
     return isset($_SESSION['csrf_token']) ? $_SESSION['csrf_token'] : '';
 }
 
+// Skip all authentication and security checks for health check endpoint
+if (is_health_check_endpoint()) {
+    // Health check endpoint requires no authentication
+    return;
+}
+
 $SecMan = new security_wrapper();
 $NetInfo = new network_info();
 $SecManager = new security_manager();
