@@ -71,14 +71,12 @@ class DelegatedUserManager {
                     username, password_hash, parent_username, display_name, email,
                     can_manage_domains, can_manage_sites, can_manage_databases, 
                     can_manage_email, can_manage_files, can_manage_backups,
-                    can_view_terminal, can_manage_wordpress,
-                    allowed_domains, created_by
+                    can_view_terminal, can_manage_wordpress, created_by
                 ) VALUES (
                     :username, :password_hash, :parent_username, :display_name, :email,
                     :can_manage_domains, :can_manage_sites, :can_manage_databases,
                     :can_manage_email, :can_manage_files, :can_manage_backups,
-                    :can_view_terminal, :can_manage_wordpress,
-                    :allowed_domains, :created_by
+                    :can_view_terminal, :can_manage_wordpress, :created_by
                 )
             ");
             
@@ -97,7 +95,6 @@ class DelegatedUserManager {
                 ':can_manage_backups' => ($data['can_manage_backups'] ?? false) ? 1 : 0,
                 ':can_view_terminal' => ($data['can_view_terminal'] ?? false) ? 1 : 0,
                 ':can_manage_wordpress' => ($data['can_manage_wordpress'] ?? false) ? 1 : 0,
-                ':allowed_domains' => isset($data['allowed_domains']) ? json_encode($data['allowed_domains']) : null,
                 ':created_by' => $created_by
             ]);
             
@@ -286,7 +283,7 @@ class DelegatedUserManager {
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
                        can_view_terminal, can_manage_wordpress,
-                       allowed_domains, is_active, last_login, created_at
+                       is_active, last_login, created_at
                 FROM delegated_users 
                 WHERE {$where_clause}
                 ORDER BY created_at DESC
@@ -319,7 +316,7 @@ class DelegatedUserManager {
                        can_manage_domains, can_manage_sites, can_manage_databases,
                        can_manage_email, can_manage_files, can_manage_backups,
                        can_view_terminal, can_manage_wordpress,
-                       allowed_domains, is_active, last_login, created_at
+                       is_active, last_login, created_at
                 FROM delegated_users 
                 WHERE {$where_clause}
                 ORDER BY parent_username, created_at DESC
@@ -361,7 +358,7 @@ class DelegatedUserManager {
                 'display_name', 'email', 'can_manage_domains', 'can_manage_sites',
                 'can_manage_databases', 'can_manage_email', 'can_manage_files',
                 'can_manage_backups', 'can_view_terminal', 'can_manage_wordpress',
-                'allowed_domains', 'is_active'
+                'is_active'
             ];
             
             $update_fields = [];
@@ -377,9 +374,7 @@ class DelegatedUserManager {
             foreach ($allowed_fields as $field) {
                 if (array_key_exists($field, $data)) {
                     $update_fields[] = "$field = :$field";
-                    if ($field === 'allowed_domains' && is_array($data[$field])) {
-                        $params[":$field"] = json_encode($data[$field]);
-                    } elseif (in_array($field, $boolean_fields)) {
+                    if (in_array($field, $boolean_fields)) {
                         // Convert boolean to integer for MySQL TINYINT columns
                         $params[":$field"] = $data[$field] ? 1 : 0;
                     } else {
